## Summary

What does this PR do?

## Related Issues

Closes #

## Test Plan

How was this tested?

## Checklist

- [ ] Tests added/updated
- [ ] Documentation updated (if applicable)
- [ ] Linting, formatting, and type checks pass
- [ ] DETECTION_MATRIX.md regenerated (if test payloads changed)
- [ ] Conventional commit message used
